@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -67,62 +67,9 @@ public class CurrencyNames_ee extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "ALL", "ALL" },
-            { "ANG", "ANG" },
-            { "ARS", "ARS" },
             { "AUD", "AU$" },
-            { "AWG", "AWG" },
-            { "BAM", "BAM" },
-            { "BBD", "BBD" },
-            { "BGN", "BGN" },
-            { "BMD", "BMD" },
-            { "BOB", "BOB" },
-            { "BSD", "BSD" },
-            { "BYN", "BYN" },
-            { "BZD", "BZD" },
-            { "CHF", "CHF" },
-            { "CLP", "CLP" },
-            { "COP", "COP" },
-            { "CRC", "CRC" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CZK", "CZK" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "FKP", "FKP" },
             { "GHS", "GH\u20b5" },
-            { "GIP", "GIP" },
-            { "GTQ", "GTQ" },
-            { "GYD", "GYD" },
-            { "HNL", "HNL" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
-            { "ISK", "ISK" },
-            { "JMD", "JMD" },
-            { "KYD", "KYD" },
-            { "MDL", "MDL" },
-            { "MKD", "MKD" },
-            { "NIO", "NIO" },
-            { "NOK", "NOK" },
-            { "PAB", "PAB" },
-            { "PEN", "PEN" },
-            { "PLN", "PLN" },
-            { "PYG", "PYG" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "SAR", "SAR" },
-            { "SEK", "SEK" },
-            { "SRD", "SRD" },
             { "THB", "\u0e3f" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
-            { "UAH", "UAH" },
-            { "UYU", "UYU" },
-            { "VEF", "VEF" },
-            { "ZAR", "ZAR" },
             { "adp", "andorraga peseta" },
             { "aed", "united arab emiratesga dirham" },
             { "afa", "afghanistanga afghani (1927\u20132002)" },
@@ -337,7 +284,8 @@ public class CurrencyNames_ee extends OpenListResourceBundle {
             { "shp", "saint helenaga pound" },
             { "sit", "slovaniaga tolar" },
             { "skk", "slovakga koruna" },
-            { "sll", "sierra leonega leone" },
+            { "sle", "sierra leonega leone" },
+            { "sll", "sierra leonega leone (1964\u20142022)" },
             { "sos", "somaliaga shilling" },
             { "srd", "surinamga dollar" },
             { "srg", "surinamega guilder" },
