@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -72,11 +68,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
                "\u683c\u6797\u5a01\u6cbb\u6807\u51c6\u65f6\u95f4",
+               "GMT",
                "",
+               "GMT",
                "",
-               "",
-               "",
-               "",
+               "GMT",
             };
         final String[] Acre = new String[] {
                "\u827e\u514b\u6807\u51c6\u65f6\u95f4",
@@ -104,11 +100,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Cuba = new String[] {
                "\u53e4\u5df4\u6807\u51c6\u65f6\u95f4",
-               "",
+               "CST",
                "\u53e4\u5df4\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "CDT",
                "\u53e4\u5df4\u65f6\u95f4",
-               "",
+               "CT",
             };
         final String[] Fiji = new String[] {
                "\u6590\u6d4e\u6807\u51c6\u65f6\u95f4",
@@ -182,6 +178,14 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "\u51ef\u897f\u7ad9\u65f6\u95f4",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "\u667a\u5229\u6807\u51c6\u65f6\u95f4",
                "",
@@ -192,11 +196,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] China = new String[] {
                "\u4e2d\u56fd\u6807\u51c6\u65f6\u95f4",
-               "",
+               "CST",
                "\u4e2d\u56fd\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "CDT",
                "\u4e2d\u56fd\u65f6\u95f4",
-               "",
+               "CT",
             };
         final String[] Cocos = new String[] {
                "\u79d1\u79d1\u65af\u7fa4\u5c9b\u65f6\u95f4",
@@ -224,19 +228,19 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Japan = new String[] {
                "\u65e5\u672c\u6807\u51c6\u65f6\u95f4",
-               "",
+               "JST",
                "\u65e5\u672c\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "JDT",
                "\u65e5\u672c\u65f6\u95f4",
-               "",
+               "JT",
             };
         final String[] Korea = new String[] {
                "\u97e9\u56fd\u6807\u51c6\u65f6\u95f4",
-               "",
+               "KST",
                "\u97e9\u56fd\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "KST",
                "\u97e9\u56fd\u65f6\u95f4",
-               "",
+               "KST",
             };
         final String[] Nauru = new String[] {
                "\u8bfa\u9c81\u65f6\u95f4",
@@ -264,11 +268,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Samoa = new String[] {
                "\u8428\u6469\u4e9a\u6807\u51c6\u65f6\u95f4",
-               "",
+               "SST",
                "\u8428\u6469\u4e9a\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "SST",
                "\u8428\u6469\u4e9a\u65f6\u95f4",
-               "",
+               "SST",
             };
         final String[] Syowa = new String[] {
                "\u662d\u548c\u57fa\u5730\u65f6\u95f4",
@@ -286,13 +290,21 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
                "\u4e1c\u52a0\u65f6\u95f4",
                "",
             };
+        final String[] Yukon = new String[] {
+               "\u80b2\u7a7a\u65f6\u95f4",
+               "MST",
+               "",
+               "MST",
+               "",
+               "MST",
+            };
         final String[] Alaska = new String[] {
                "\u963f\u62c9\u65af\u52a0\u6807\u51c6\u65f6\u95f4",
-               "",
+               "AKST",
                "\u963f\u62c9\u65af\u52a0\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "AKDT",
                "\u963f\u62c9\u65af\u52a0\u65f6\u95f4",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "\u4e9a\u9a6c\u900a\u6807\u51c6\u65f6\u95f4",
@@ -352,11 +364,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Israel = new String[] {
                "\u4ee5\u8272\u5217\u6807\u51c6\u65f6\u95f4",
-               "",
+               "IST",
                "\u4ee5\u8272\u5217\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "IDT",
                "\u4ee5\u8272\u5217\u65f6\u95f4",
-               "",
+               "IT",
             };
         final String[] Kosrae = new String[] {
                "\u79d1\u65af\u745e\u65f6\u95f4",
@@ -376,11 +388,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Moscow = new String[] {
                "\u83ab\u65af\u79d1\u6807\u51c6\u65f6\u95f4",
-               "",
+               "MSK",
                "\u83ab\u65af\u79d1\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "MSK",
                "\u83ab\u65af\u79d1\u65f6\u95f4",
-               "",
+               "MSK",
             };
         final String[] Ponape = new String[] {
                "\u6ce2\u7eb3\u4f69\u65f6\u95f4",
@@ -408,11 +420,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Taipei = new String[] {
                "\u53f0\u5317\u6807\u51c6\u65f6\u95f4",
-               "",
+               "CST",
                "\u53f0\u5317\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "CDT",
                "\u53f0\u5317\u65f6\u95f4",
-               "",
+               "CT",
             };
         final String[] Tuvalu = new String[] {
                "\u5410\u74e6\u9c81\u65f6\u95f4",
@@ -600,11 +612,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Atlantic = new String[] {
                "\u5927\u897f\u6d0b\u6807\u51c6\u65f6\u95f4",
-               "",
+               "AST",
                "\u5927\u897f\u6d0b\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "ADT",
                "\u5927\u897f\u6d0b\u65f6\u95f4",
-               "",
+               "AT",
             };
         final String[] Brasilia = new String[] {
                "\u5df4\u897f\u5229\u4e9a\u6807\u51c6\u65f6\u95f4",
@@ -616,11 +628,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Chamorro = new String[] {
                "\u67e5\u83ab\u6d1b\u65f6\u95f4",
+               "ChST",
                "",
+               "ChST",
                "",
-               "",
-               "",
-               "",
+               "ChST",
             };
         final String[] Colombia = new String[] {
                "\u54e5\u4f26\u6bd4\u4e9a\u6807\u51c6\u65f6\u95f4",
@@ -664,11 +676,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Pakistan = new String[] {
                "\u5df4\u57fa\u65af\u5766\u6807\u51c6\u65f6\u95f4",
-               "",
+               "PKT",
                "\u5df4\u57fa\u65af\u5766\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "PKST",
                "\u5df4\u57fa\u65af\u5766\u65f6\u95f4",
-               "",
+               "PKT",
             };
         final String[] Paraguay = new String[] {
                "\u5df4\u62c9\u572d\u6807\u51c6\u65f6\u95f4",
@@ -728,11 +740,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Hong_Kong = new String[] {
                "\u9999\u6e2f\u6807\u51c6\u65f6\u95f4",
-               "",
+               "HKT",
                "\u9999\u6e2f\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "HKST",
                "\u9999\u6e2f\u65f6\u95f4",
-               "",
+               "HKT",
             };
         final String[] Indochina = new String[] {
                "\u5370\u5ea6\u652f\u90a3\u65f6\u95f4",
@@ -766,14 +778,6 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
                "\u8c6a\u52cb\u7235\u5c9b\u65f6\u95f4",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "\u9ea6\u89c9\u7406\u65f6\u95f4",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "\u9a6c\u53ef\u8428\u65af\u65f6\u95f4",
                "",
@@ -808,11 +812,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Volgograd = new String[] {
                "\u4f0f\u5c14\u52a0\u683c\u52d2\u6807\u51c6\u65f6\u95f4",
-               "",
+               "MSK",
                "\u4f0f\u5c14\u52a0\u683c\u52d2\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "MSK",
                "\u4f0f\u5c14\u52a0\u683c\u52d2\u65f6\u95f4",
-               "",
+               "MSK",
             };
         final String[] Azerbaijan = new String[] {
                "\u4e9a\u585e\u62dc\u7136\u6807\u51c6\u65f6\u95f4",
@@ -888,11 +892,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] New_Zealand = new String[] {
                "\u7ebd\u897f\u5170\u6807\u51c6\u65f6\u95f4",
-               "",
+               "NZST",
                "\u7ebd\u897f\u5170\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "NZDT",
                "\u7ebd\u897f\u5170\u65f6\u95f4",
-               "",
+               "NZT",
             };
         final String[] Novosibirsk = new String[] {
                "\u65b0\u897f\u4f2f\u5229\u4e9a\u6807\u51c6\u65f6\u95f4",
@@ -904,11 +908,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Philippines = new String[] {
                "\u83f2\u5f8b\u5bbe\u6807\u51c6\u65f6\u95f4",
-               "",
+               "PST",
                "\u83f2\u5f8b\u5bbe\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "PDT",
                "\u83f2\u5f8b\u5bbe\u65f6\u95f4",
-               "",
+               "PT",
             };
         final String[] Vladivostok = new String[] {
                "\u6d77\u53c2\u5d34\u6807\u51c6\u65f6\u95f4",
@@ -936,11 +940,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Newfoundland = new String[] {
                "\u7ebd\u82ac\u5170\u6807\u51c6\u65f6\u95f4",
-               "",
+               "NST",
                "\u7ebd\u82ac\u5170\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "NDT",
                "\u7ebd\u82ac\u5170\u65f6\u95f4",
-               "",
+               "NT",
             };
         final String[] Turkmenistan = new String[] {
                "\u571f\u5e93\u66fc\u6807\u51c6\u65f6\u95f4",
@@ -984,27 +988,27 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "\u4e2d\u975e\u65f6\u95f4",
+               "CAT",
                "",
+               "CAT",
                "",
-               "",
-               "",
-               "",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "\u4e1c\u975e\u65f6\u95f4",
+               "EAT",
                "",
+               "EAT",
                "",
-               "",
-               "",
-               "",
+               "EAT",
             };
         final String[] Africa_Western = new String[] {
                "\u897f\u975e\u6807\u51c6\u65f6\u95f4",
-               "",
+               "WAT",
                "\u897f\u975e\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "WAT",
                "\u897f\u975e\u65f6\u95f4",
-               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "\u675c\u8499\u675c\u6bd4\u5c14\u65f6\u95f4",
@@ -1016,67 +1020,67 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Europe_Central = new String[] {
                "\u4e2d\u6b27\u6807\u51c6\u65f6\u95f4",
-               "",
+               "CET",
                "\u4e2d\u6b27\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "CEST",
                "\u4e2d\u6b27\u65f6\u95f4",
-               "",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "\u4e1c\u6b27\u6807\u51c6\u65f6\u95f4",
-               "",
+               "EET",
                "\u4e1c\u6b27\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "EEST",
                "\u4e1c\u6b27\u65f6\u95f4",
-               "",
+               "EET",
             };
         final String[] Europe_Western = new String[] {
                "\u897f\u6b27\u6807\u51c6\u65f6\u95f4",
-               "",
+               "WET",
                "\u897f\u6b27\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "WEST",
                "\u897f\u6b27\u65f6\u95f4",
-               "",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "\u58a8\u897f\u54e5\u592a\u5e73\u6d0b\u6807\u51c6\u65f6\u95f4",
-               "",
+               "MST",
                "\u58a8\u897f\u54e5\u592a\u5e73\u6d0b\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "MDT",
                "\u58a8\u897f\u54e5\u592a\u5e73\u6d0b\u65f6\u95f4",
-               "",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "\u5357\u975e\u6807\u51c6\u65f6\u95f4",
+               "SAST",
                "",
+               "SAST",
                "",
-               "",
-               "",
-               "",
+               "SAST",
             };
         final String[] America_Central = new String[] {
                "\u4e2d\u90e8\u6807\u51c6\u65f6\u95f4",
-               "",
+               "CST",
                "\u4e2d\u90e8\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "CDT",
                "\u4e2d\u90e8\u65f6\u95f4",
-               "",
+               "CT",
             };
         final String[] America_Eastern = new String[] {
                "\u4e1c\u90e8\u6807\u51c6\u65f6\u95f4",
-               "",
+               "EST",
                "\u4e1c\u90e8\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "EST",
                "\u4e1c\u90e8\u65f6\u95f4",
-               "",
+               "EST",
             };
         final String[] America_Pacific = new String[] {
                "\u592a\u5e73\u6d0b\u6807\u51c6\u65f6\u95f4",
-               "",
+               "PST",
                "\u592a\u5e73\u6d0b\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "PDT",
                "\u592a\u5e73\u6d0b\u65f6\u95f4",
-               "",
+               "PT",
             };
         final String[] French_Southern = new String[] {
                "\u6cd5\u56fd\u5357\u65b9\u53ca\u5357\u6781\u65f6\u95f4",
@@ -1096,11 +1100,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Hawaii_Aleutian = new String[] {
                "\u590f\u5a01\u5937-\u963f\u7559\u7533\u6807\u51c6\u65f6\u95f4",
-               "",
+               "HST",
                "\u590f\u5a01\u5937-\u963f\u7559\u7533\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "HST",
                "\u590f\u5a01\u5937-\u963f\u7559\u7533\u65f6\u95f4",
-               "",
+               "HST",
             };
         final String[] Phoenix_Islands = new String[] {
                "\u51e4\u51f0\u7fa4\u5c9b\u65f6\u95f4",
@@ -1120,11 +1124,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] America_Mountain = new String[] {
                "\u5c71\u533a\u6807\u51c6\u65f6\u95f4",
-               "",
+               "MST",
                "\u5c71\u533a\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "MST",
                "\u5c71\u533a\u65f6\u95f4",
-               "",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "\u9a6c\u7ecd\u5c14\u7fa4\u5c9b\u65f6\u95f4",
@@ -1152,27 +1156,27 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Australia_Central = new String[] {
                "\u6fb3\u6d32\u4e2d\u90e8\u6807\u51c6\u65f6\u95f4",
-               "",
+               "ACST",
                "\u6fb3\u6d32\u4e2d\u90e8\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "ACDT",
                "\u6fb3\u6d32\u4e2d\u90e8\u65f6\u95f4",
-               "",
+               "ACT",
             };
         final String[] Australia_Eastern = new String[] {
                "\u6fb3\u6d32\u4e1c\u90e8\u6807\u51c6\u65f6\u95f4",
-               "",
+               "AEST",
                "\u6fb3\u6d32\u4e1c\u90e8\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "AEDT",
                "\u6fb3\u6d32\u4e1c\u90e8\u65f6\u95f4",
-               "",
+               "AET",
             };
         final String[] Australia_Western = new String[] {
                "\u6fb3\u6d32\u897f\u90e8\u6807\u51c6\u65f6\u95f4",
-               "",
+               "AWST",
                "\u6fb3\u6d32\u897f\u90e8\u590f\u4ee4\u65f6\u95f4",
-               "",
+               "AWDT",
                "\u6fb3\u6d32\u897f\u90e8\u65f6\u95f4",
-               "",
+               "AWT",
             };
         final String[] Greenland_Eastern = new String[] {
                "\u683c\u9675\u5170\u4e1c\u90e8\u6807\u51c6\u65f6\u95f4",
@@ -1192,27 +1196,27 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             };
         final String[] Indonesia_Central = new String[] {
                "\u5370\u5c3c\u4e2d\u90e8\u65f6\u95f4",
+               "WITA",
                "",
+               "WITA",
                "",
-               "",
-               "",
-               "",
+               "WITA",
             };
         final String[] Indonesia_Eastern = new String[] {
                "\u5370\u5c3c\u4e1c\u90e8\u65f6\u95f4",
+               "WIT",
                "",
+               "WIT",
                "",
-               "",
-               "",
-               "",
+               "WIT",
             };
         final String[] Indonesia_Western = new String[] {
                "\u5370\u5c3c\u897f\u90e8\u65f6\u95f4",
+               "WIB",
                "",
+               "WIB",
                "",
-               "",
-               "",
-               "",
+               "WIB",
             };
         final String[] Kazakhstan_Eastern = new String[] {
                "\u4e1c\u54c8\u8428\u514b\u65f6\u95f4",
@@ -1291,7 +1295,6 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1300,7 +1303,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1387,7 +1390,6 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1402,11 +1404,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "Europe/Dublin",
                 new String[] {
                     "\u683c\u6797\u5a01\u6cbb\u6807\u51c6\u65f6\u95f4",
-                    "",
+                    "GMT",
                     "\u7231\u5c14\u5170\u6807\u51c6\u65f6\u95f4",
+                    "IST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Jersey", GMT },
@@ -1414,11 +1416,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "Europe/London",
                 new String[] {
                     "\u683c\u6797\u5a01\u6cbb\u6807\u51c6\u65f6\u95f4",
-                    "",
+                    "GMT",
                     "\u82f1\u56fd\u590f\u4ee4\u65f6\u95f4",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Madrid", Europe_Central },
@@ -1450,7 +1452,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1476,11 +1478,11 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "Europe/Belfast",
                 new String[] {
                     "\u683c\u6797\u5a01\u6cbb\u6807\u51c6\u65f6\u95f4",
-                    "",
+                    "GMT",
                     "\u82f1\u56fd\u590f\u4ee4\u65f6\u95f4",
+                    "BST",
                     "",
-                    "",
-                    "",
+                    "GMT",
                 }
             },
             { "Europe/Tallinn", Europe_Eastern },
@@ -1526,7 +1528,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1576,7 +1578,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1612,7 +1614,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1657,7 +1659,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,9 +1699,10 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1909,6 +1912,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "\u9a6c\u7ea6\u7279\u5c9b" },
             { "timezone.excity.Indian/Reunion", "\u7559\u5c3c\u65fa\u5c9b" },
             { "timezone.excity.Pacific/Easter", "\u590d\u6d3b\u5c9b" },
+            { "timezone.excity.Pacific/Kanton", "\u574e\u987f" },
             { "timezone.excity.Pacific/Kosrae", "\u79d1\u65af\u745e" },
             { "timezone.excity.Pacific/Majuro", "\u9a6c\u6731\u8bfa" },
             { "timezone.excity.Pacific/Midway", "\u4e2d\u9014\u5c9b" },
@@ -2129,6 +2133,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Bougainville", "\u5e03\u5e72\u7ef4\u5c14" },
             { "timezone.excity.Pacific/Port_Moresby", "\u83ab\u58eb\u6bd4\u6e2f" },
             { "timezone.excity.America/Cambridge_Bay", "\u5251\u6865\u6e7e" },
+            { "timezone.excity.America/Ciudad_Juarez", "\u534e\u96f7\u65af\u57ce" },
             { "timezone.excity.America/Coral_Harbour", "\u963f\u8482\u79d1\u80af" },
             { "timezone.excity.America/Indiana/Vevay", "\u5370\u7b2c\u5b89\u90a3\u5dde\u7ef4\u5a01" },
             { "timezone.excity.America/Lower_Princes", "\u4e0b\u592a\u5b50\u533a" },
